import 'package:dart_redis_cluster_key_slot/dart_redis_cluster_key_slot.dart';
import 'package:spec/spec.dart';

final tests = <String, int>{
  '123465': 1492,
  'foobar': 12325,
  'abcdefghijklmnopqrstuvwxyz': 9132,
  r'gsdfhan$%^&*(sdgsdnhshcs': 15532,
  'abc{foobar}': 12325,
  '{foobar}': 12325,
  'h8a9sd{foobar}}{asd}}': 12325,
  '{foobar': 16235,
  'foobar{}': 4435,
  '{{foobar}': 16235,
  'éêe': 13690,
  'àâa': 3872,
  '漢字': 14191,
  '汉字': 16196,
  '호텔': 4350,
  '\uD83D\uDC80': 9284,
  '\uD800\uDC00': 11620, // surrogate pair
  '{}foobar': 14573,
};

final testsMulti = <String>[
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz',
  'abcdefghijklmnopqrstuvwxyz'
];

const testsMultiResult = 9132;

void main() {
  group('single hash: generate()', () {
    test('generate a correct hash from string', () {
      for (final entry in tests.entries) {
        expect(generate(entry.key)).toEqual(entry.value);
      }
    });
  });
  group('multiple hashes: generateMulti()', () {
    test('generate a correct hash from multiple strings', () {
      expect(generateMulti(testsMulti)).toEqual(testsMultiResult);
    });

    test(
        'returns -1 if any of the keys generates a different hash slot than the rest',
        () {
      expect(generateMulti(tests.keys.toList())).toEqual(-1);
    });
  });
}
